@@ -6,7 +6,7 @@ use warnings;
 
 use base 'Test::Builder::Module';
 
-our $VERSION = '0.25';
+our $VERSION = '0.26';
 our $AUTHORITY = 'cpan:JJNAPIORK';
 
 use Config::Any;
@@ -1098,6 +1098,12 @@ set the previously mentioned option 'force_drop_table' to true as well, or we
 will attempt to create tables and populate them when they are already populated
 and created.
 
+=item deploy_db
+
+By default a fresh version of the schema is deployed when 'Test::DBIx::Class'
+is invoked.  If you want to skip the schema deployment and instead connect
+to an already existing and populated database, set this option to false.
+
 =item traits
 
 Traits are L<Moose::Role>s that are applied to the class managing the connection
@@ -1394,6 +1400,8 @@ L<DBIx::Class>, L<DBIx::Class::Schema::PopulateMore>, L<DBIx::Class::Fixtures>
     colinnewell
     rbuels
     wlk
+    yanick
+    hippich
 
 =head1 COPYRIGHT & LICENSE
 
